### Load Libraries & Data


## Libraries
library(tidyverse)
library(lmerTest)
library(MuMIn)

## Data
concept <- read.csv("data//conceptions.csv")
climate <- read.csv("data//climate.csv")
pheno <- read.csv("data//phenology.csv")


### Patterns of phenology over time
months <- c("January","February","March","April","May","June","July","August","September","October","November","December") 
## Convert month to numeric
pheno$Month <- match(as.character(pheno$Month), months)

## Create a date column
pheno[,"date"] <- as.Date(paste(pheno$Year,pheno$Month,1, sep="-"), format=c("%Y-%m-%d"))


## monthly patterns
monthly <- pheno %>%  group_by(date, Year, Month)%>% summarize_at(vars(ML:RF), mean, na.rm=T) %>% data.frame()

## all vars
longMonth <- monthly  %>% gather(plantPheno, abundance, ML:RF)


### Climate patterns overtime
## Summarize by month
monthlyClim <- climate %>% group_by(Year, Month) %>% summarize_at(vars(Max.temp:Sun.Hour), mean) %>% data.frame()

## Create a date column
monthlyClim[,"date"] <- as.Date(paste(monthlyClim$Year,monthlyClim$Month,1, sep="-"), format=c("%Y-%m-%d"))

### Combine climate and phenology
climPheno <- merge(monthly, monthlyClim, by=c("date","Year","Month"), all=T)



#### Create conceptions data


## Conceptions occur 163 days before birth

## Summarize by month
monthlyConcept <- concept %>% group_by(YearCon, MonthCon) %>% summarize(conceptions=length(MonthCon))


## Create a date column
monthlyConcept[,"date"] <- as.Date(paste(monthlyConcept$YearCon,monthlyConcept$MonthCon,1, sep="-"), format=c("%Y-%m-%d")) 
monthlyConcept <- data.frame(monthlyConcept)

## Create relative conceptions per year
monthlyConcept <- monthlyConcept %>% group_by(YearCon) %>%  mutate(freqConcept = conceptions/sum(conceptions, na.rm=T)) %>% data.frame()


## Join with phenology and climate
allvars <- merge(climPheno, monthlyConcept, by="date", all.x=T)
allvars[is.na(allvars$conceptions),"conceptions"] <- 0 ## label no conceptions
allvars[is.na(allvars$freqConcept),"freqConcept"] <- 0 ## label no conceptions


### Create births data

## Summarize by month
monthlyConcept <- concept %>% group_by(YearDOB, MonthDOB) %>% summarize(births=length(DOB))


## Create a date column
monthlyConcept[,"date"] <- as.Date(paste(monthlyConcept$YearDOB,monthlyConcept$MonthDOB,1, sep="-"), format=c("%Y-%m-%d")) 
monthlyConcept <- data.frame(monthlyConcept)

## Create relative conceptions per year
monthlyConcept <- monthlyConcept %>% group_by(YearDOB) %>%  mutate(freqBirth = births/sum(births, na.rm=T)) %>% filter(YearDOB != 2020) %>%  data.frame() 

## Join with phenology and climate
allvars2 <- merge(climPheno, monthlyConcept, by="date", all.x=T)
allvars2[is.na(allvars2$births),"births"] <- 0 ## label no births
allvars2[is.na(allvars2$freqBirth),"freqBirth"] <- 0 ## label no births
